import express,{Router, Request, Response} from 'express';
import {Project} from '../models/Project';
import {myDataSource} from '../app-data-source';
import { User } from '../models/User';

const router:Router = express.Router();
const dataSource = myDataSource;


router.get('/',async (req:Request, res:Response): Promise<Response>=> {
    const projects:Project[] = await dataSource.manager.find(Project)
    return res.send({projects})
})

router.get("/project_id/:project_id",async (req:Request, res:Response): Promise<Response> => {
    const project = await dataSource
    .createQueryBuilder()
    .select("project")
    .from(Project, "project")
    // .where("user.workerInProjects= :projects", {projects.id : req.params.project_id } )
    // .innerJoinAndSelect('project.workers','user')
    .leftJoinAndSelect('project.admin','user')
    .where("project.id = :id", { id: req.params.project_id })
    .getOne()

    if (!project) return res.status(404).send({Message:'no such project in the base'})
    return res.send({project})
})

router.post('/', async (req:Request, res:Response): Promise<Response> => {
    if (!req.body) return res.status(400).send({Message:'problem in incoming req.body'})
    const {title, dateDue,color,department, userId,workers,tasks}= req.body;
    const user = await dataSource
    .createQueryBuilder()
    .select("user")
    .from(User, "user")
    .where("user.id = :id", { id: userId })
    .getOne()
    if(!user) return res.status(404).send({Message:'user not found'})
    const project : Project= new Project()
    project.title = title;
    project.color = color; 
    project.dateDue = dateDue || null;
    project.department = department;
    project.workers = workers|| null;
    project.tasks = tasks || null;
    project.admin = user;
    await project.save()
    return res.send({project})
})


router.get('/:userId', async (req : Request, res : Response): Promise<Response>=>{
    const userId:string = req.params.userId
    const user = await dataSource
    .createQueryBuilder()
    .select("user")
    .from(User, "user")
    .where("user.id = :id", { id: userId })
    .getOne()
    console.log('user ', user)
    const userProjects = await dataSource
    .createQueryBuilder()
    .select('project')
    .from(Project, "project")
    .where("Project_adminId = :id", { id: userId })
    return res.send({userProjects})
})

export default router;
